import { getConfig } from './getConfig.js';
var ADOBE_ORG_ID = '05FF6243578784B37F000101@AdobeOrg';
var DEFAULT_DEMDEX_VERSION = '3.3.0';
var TRACKING_SERVER = 'schibstedspain.d3.sc.omtrdc.net';
var TIMES_TO_RETRY = 80;
var TIME_BETWEEN_RETRIES = 15;
var SERVERS = {
  trackingServer: TRACKING_SERVER,
  trackingServerSecure: TRACKING_SERVER
};
var mcvid;

var getDemdex = function getDemdex() {
  return window.Visitor && window.Visitor.getInstance(ADOBE_ORG_ID, SERVERS);
};

var getMarketingCloudVisitorID = function getMarketingCloudVisitorID(demdex) {
  return demdex && demdex.getMarketingCloudVisitorID();
};

var getAdobeVisitorData = function getAdobeVisitorData() {
  var demdex = getDemdex() || {};
  var _demdex$version = demdex.version,
      version = _demdex$version === void 0 ? DEFAULT_DEMDEX_VERSION : _demdex$version;
  var trackingServer = SERVERS.trackingServer;
  return Promise.resolve({
    trackingServer: trackingServer,
    version: version
  });
};

var deprecatedGetAdobeMCVisitorID = function deprecatedGetAdobeMCVisitorID() {
  if (mcvid) return Promise.resolve(mcvid);
  return new Promise(function (resolve) {
    function retry(retries) {
      if (retries === 0) return resolve('');
      var demdex = getDemdex();
      mcvid = getMarketingCloudVisitorID(demdex);
      return mcvid ? resolve(mcvid) : window.setTimeout(function () {
        return retry(--retries);
      }, TIME_BETWEEN_RETRIES);
    }

    retry(TIMES_TO_RETRY);
  });
};

var importVisitorApiAndGetAdobeMCVisitorID = function importVisitorApiAndGetAdobeMCVisitorID() {
  return import('./adobeVisitorApi.js').then(function () {
    if (mcvid) return Promise.resolve(mcvid);
    var demdex = getDemdex();
    mcvid = getMarketingCloudVisitorID(demdex);
    return mcvid;
  });
};

var getAdobeMCVisitorID = function getAdobeMCVisitorID() {
  var getCustomAdobeVisitorId = getConfig('getCustomAdobeVisitorId');

  if (typeof getCustomAdobeVisitorId === 'function') {
    return getCustomAdobeVisitorId();
  }

  return getConfig('importAdobeVisitorId') === true ? importVisitorApiAndGetAdobeMCVisitorID() : deprecatedGetAdobeMCVisitorID();
};

export { getAdobeVisitorData, getAdobeMCVisitorID };